bb003 test

# Pulp Fiction

There was an accitental killing of a man. The man was shot in the head - so the car and both, Vincent and Jules, are spleatted with blood. This must be brought back to order. The one who helps here is Mr. Wulf.

## Clean up Car

Description
  At a glance the car must look normally.
Rationale

  The car is over and over bloody.

Depends on:
  CreateOrder
Dependent
  CleanUpSeats, DetergentForCar
Id
  CleanUpCar
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  VincentAndJules
Status
  not done
Class
  detailable

## Clean up Seats

Description
  The seats must be cleaned.
Rationale

  It is not possible to completely clean the seats - therefore they will additionally be covered.

Depends on:
  CleanUpCar
Dependent
  CoverWithBlankets, RoughlyCleanUpSeats
Id
  CleanUpSeats
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  detailable

## Clean up Vincent and Jules

Description
  Vincent and Jules must be cleaned.
Rationale

  Both are splattered with blood.

Depends on:
  CreateOrder
Dependent
  SoapAndColdWater, TakeCareOfClothing, TakeOff
Id
  CleanUpVicentAndJules
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  VincentAndJules
Status
  not done
Class
  detailable

## Corpse In Trunk

Description
  The corpse must be put into the trunk.
Rationale

  The corpse can be transported in this way without any notice of anybody else.

Depends on:
  DeadManDisapper
Id
  CorpseInTrunk
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Cover with Blankets

Description
  The seats must be covered with blankets after they are roughly cleaned.
Depends on:
  CleanUpSeats, RoughlyCleanUpSeats
Id
  CoverWithBlankets
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Create Order

Description
  The accidental death of a man must be disguised.
Rationale

  There are some different things which must be cleaned and others which must vanish.

Note
  There is only 40 minutes time to do the whole job.
Dependent
  CleanUpCar, CleanUpVicentAndJules, DeadManDisapper
Id
  CreateOrder
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  VincentAndJules
Status
  not done
Class
  detailable

## Dead Man Disappear

Description
  The dead man must disappear.
Rationale

  The accidental killed man must vanish.

Depends on:
  CreateOrder
Dependent
  CorpseInTrunk
Id
  DeadManDisapper
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  VincentAndJules
Status
  not done
Class
  detailable

## Detergent for Car

Description
  The car must be cleaned with detergents.
Rationale

  The car is over and over bloody - so detergents are needed.

Note
  The detergents are place in the kitchen under the sink.
Depends on:
  CleanUpCar
Id
  DetergentForCar
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Roughly Clean up Seats

Description
  The seats must be roughly cleaned.
Rationale

  It is not possible to completely clean the back seat.

Depends on:
  CleanUpSeats
Dependent
  CoverWithBlankets
Id
  RoughlyCleanUpSeats
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Soap and Cold Water

Description
  Vincent and Jules must clean themselves with soap and cold water.
Rationale

  They are bloody.

Depends on:
  CleanUpVicentAndJules, TakeOff
Id
  SoapAndColdWater
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Take Care of Clothing

Description
  Vincent and Jules' clothing must be taken care off.
Rationale

  It's bloody - Otto the refuse collector should not see this.

Depends on:
  CleanUpVicentAndJules, TakeOff
Id
  TakeCareOfClothing
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Take Off

Description
  Vincent and Jules must take off their whole clothing.
Rationale

  It's bloody.

Note
  Wulf: 'Down to the bare ass'.
Depends on:
  CleanUpVicentAndJules
Dependent
  SoapAndColdWater, TakeCareOfClothing
Id
  TakeOff
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable